-- physics setup module
physicsGenerator = require("physics")

-- setup physics
function love.load()

	setupPhysicsEnvironment()
end

-- update interval in seconds
interval = 1/60.0
-- maximum frame skip
maxsteps = 5
-- accumulator
accum = 0

-- nothing too heavy
function love.update(dt)
	local steps = 0
	-- update the simulation
	accum = accum + dt
	while accum >= interval do
		-- update the simulation
		physicsUpdate(interval)
		
		-- handle keyboard input
		if love.keyboard.isDown("a") then
			--rotate worm counterclockwise
			objects.wormsegment1.body:applyForce(500 * math.sin(objects.wormsegment1.body:getAngle() + math.pi/2), 500 * math.cos(objects.wormsegment1.body:getAngle() - math.pi/2))
		elseif love.keyboard.isDown("d") then
			--rotate worm clockwise
			objects.wormsegment1.body:applyForce(-500 * math.sin(objects.wormsegment1.body:getAngle() + math.pi/2), -500 * math.cos(objects.wormsegment1.body:getAngle() - math.pi/2))
		end
		
		--handle input touches
		local touches = love.touch.getTouches()
		for index, id in ipairs(touches) do
			local x, y = love.touch.getPosition(id)
			if x < love.graphics.getWidth() / 2 then
				--rotate worm counterclockwise
				break;
			elseif x > love.graphics.getWidth() / 2 then
				--rotate worm clockwise
				break;
			end
		end
		
		accum = accum - interval
		steps = steps + 1
		if steps >= maxsteps then
			break
		end
	end
end

function love.draw()
	--love.graphics.setColor(72, 160, 14) -- set the drawing color to green for the ground
	--love.graphics.polygon("fill", objects.ground.body:getWorldPoints(objects.ground.shape:getPoints())) -- draw a "filled in" polygon using the ground's coordinates
	love.graphics.setColor(193, 47, 14) --set the drawing color to red for the ball
	love.graphics.circle("fill", objects.ball.body:getX(), objects.ball.body:getY(), objects.ball.shape:getRadius())
	
	love.graphics.setColor(50, 50, 50) -- set the drawing color to grey for the blocks
	love.graphics.circle("fill", objects.wormholder.body:getX(), objects.wormholder.body:getY(), objects.wormholder.shape:getRadius())
	love.graphics.polygon("fill", objects.wormsegment1.body:getWorldPoints(objects.wormsegment1.shape:getPoints()))
	love.graphics.polygon("fill", objects.wormsegment2.body:getWorldPoints(objects.wormsegment2.shape:getPoints()))
	love.graphics.polygon("fill", objects.wormsegment3.body:getWorldPoints(objects.wormsegment3.shape:getPoints()))
	
	love.graphics.setColor(255, 255, 255, 255)
	local mem = collectgarbage('count')
	mem = math.ceil(mem)
	love.graphics.print("memory:" .. mem, 0, 15)
	love.graphics.print(string.format("FPS: %.3f fps", love.timer.getFPS()), 10, love.graphics.getHeight() - 40);
	love.graphics.print(objects.wormsegment1.body:getAngle(), 0, 30)
end
