windowx = 320;
windowy = 640;
local segmentLength = 0.088 * windowy;
local segmentWidth = 0.05 * windowx;

function setupPhysicsEnvironment()
	love.physics.setMeter(64) --the height of a meter our worlds will be 64px
	world = love.physics.newWorld(0, 9.81*64, true) --create a world for the bodies to exist in with horizontal gravity of 0 and vertical gravity of 9.81
	objects = {} -- table to hold all our physical objects
	
	--create the ground
	--objects.ground = {}
	--objects.ground.body = love.physics.newBody(world, windowx/2, windowy + 40, "static")
	--objects.ground.shape = love.physics.newRectangleShape(windowx, windowy * 0.05)
	--objects.ground.fixture = love.physics.newFixture(objects.ground.body, objects.ground.shape) --attach shape to body
	
	--create a ball
	objects.ball = {}
	objects.ball.body = love.physics.newBody(world, windowx/2, windowy/2, "dynamic") --place the body in the center of the world and make it dynamic, so it can move around
	objects.ball.shape = love.physics.newCircleShape(windowx * 0.06) --the ball's shape has a radius
	objects.ball.fixture = love.physics.newFixture(objects.ball.body, objects.ball.shape, 1) -- Attach fixture to body and give it a density of 1.
	objects.ball.fixture:setRestitution(0.9) --ball bounces
	
	--create worm holder
	objects.wormholder = {}
	objects.wormholder.body = love.physics.newBody(world, windowx/2, windowy/2 + windowy/4, "static")
	objects.wormholder.shape = love.physics.newCircleShape(windowx * 0.03)
	objects.wormholder.fixture = love.physics.newFixture(objects.wormholder.body, objects.wormholder.shape)
	
	--create worm rope
	objects.wormsegment1 = {}
	objects.wormsegment1.body = love.physics.newBody(world, windowx/2, windowy/2 + windowy/4 + segmentLength/2, "dynamic")
	objects.wormsegment1.shape = love.physics.newRectangleShape(segmentWidth, segmentLength)
	objects.wormsegment1.fixture = love.physics.newFixture(objects.wormsegment1.body, objects.wormsegment1.shape)
	objects.wormsegment1.joint = love.physics.newRevoluteJoint(objects.wormholder.body, objects.wormsegment1.body, objects.wormholder.body:getX(), objects.wormholder.body:getY(), false);
	
	objects.wormsegment2 = {}
	objects.wormsegment2.body = love.physics.newBody(world, windowx/2, windowy/2 + windowy/4 + segmentLength*1.5, "dynamic")
	objects.wormsegment2.shape = love.physics.newRectangleShape(segmentWidth, segmentLength)
	objects.wormsegment2.fixture = love.physics.newFixture(objects.wormsegment2.body, objects.wormsegment2.shape)
	objects.wormsegment2.joint = love.physics.newRevoluteJoint(objects.wormsegment1.body, objects.wormsegment2.body, objects.wormsegment1.body:getX(), objects.wormsegment1.body:getY() + segmentLength/2, false);
	objects.wormsegment2.joint:setLimits (-0.9 * math.pi, 0.9 * math.pi)
	objects.wormsegment2.joint:setLimitsEnabled (true)
	objects.wormsegment2.joint:setMotorSpeed(0)
	objects.wormsegment2.joint:setMotorEnabled(true)
	objects.wormsegment2.joint:setMaxMotorTorque(80)
	
	objects.wormsegment3 = {}
	objects.wormsegment3.body = love.physics.newBody(world, windowx/2, windowy/2 + windowy/4 + segmentLength*1.5 + segmentLength, "dynamic")
	objects.wormsegment3.shape = love.physics.newRectangleShape(segmentWidth, segmentLength)
	objects.wormsegment3.fixture = love.physics.newFixture(objects.wormsegment3.body, objects.wormsegment3.shape)
	objects.wormsegment3.joint = love.physics.newRevoluteJoint(objects.wormsegment2.body, objects.wormsegment3.body, objects.wormsegment2.body:getX(), objects.wormsegment2.body:getY() + segmentLength/2, false);
	objects.wormsegment3.joint:setLimits (-0.9 * math.pi, 0.9 * math.pi)
	objects.wormsegment3.joint:setLimitsEnabled (true)
	objects.wormsegment3.joint:setMotorSpeed(0)
	objects.wormsegment3.joint:setMotorEnabled(true)
	objects.wormsegment3.joint:setMaxMotorTorque(80)
	
	--let's create a couple blocks to play around with
	--objects.block1 = {}
	--objects.block1.body = love.physics.newBody(world, 200, 550, "dynamic")
	--objects.block1.shape = love.physics.newRectangleShape(0, 0, 50, 100)
	--objects.block1.fixture = love.physics.newFixture(objects.block1.body, objects.block1.shape, 5) -- A higher density gives it more mass.
	--objects.block2 = {}
	--objects.block2.body = love.physics.newBody(world, 200, 400, "dynamic")
	--objects.block2.shape = love.physics.newRectangleShape(0, 0, 100, 50)
	--objects.block2.fixture = love.physics.newFixture(objects.block2.body, objects.block2.shape, 2)
	
	--initial graphics setup
	love.graphics.setBackgroundColor(104, 136, 248) --set the background color to blue
	love.window.setMode(windowx, windowy) --set the window dimensions, vsync on, and no antialiasing
end

-- updates the simulation
function physicsUpdate(dt)
	-- track the number of collision checks (optional)
	--nchecks = 0
	
	world:update(dt);
	
	-- todo: user defined velocities change
	-- as we add gravity before resolving collisions
	
	-- update velocity vectors
	
	-- move kinematic shapes
	
	-- move dynamic shapes
end